##  Using the 6R Classification for Application Portfolio Assessment
SAP LeanIX Reports offer powerful ways to assess one’s application portfolio with 6R classification. For example, you may want to begin modernizing applications that require minimal effort, especially in the initial stages, when it is essential to focus on learning and upskilling the team. Focusing on Applications classified under Rehost gives you applications that require minimal effort, as rehosting is a quick way to migrate to the cloud as you do not improve functionality.
You may also want to start with Applications with low business importance, migrate them to the cloud, and incorporate the learnings into your successive iterations. If something fails, your business will not be impacted majorly. Focusing on applications under Tolerate of the TIME classification narrows the scope to applications of low business importance.
You can easily narrow down such applications using the SAP LeanIX [Matrix Report](https://help.sap.com/docs/leanix/ea/matrix-report?locale=en-US&state=PRODUCTION&version=CLOUD). You can identify which applications are categorized as Tolerate under the TIME classification and Rehost under the 6R classification.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a401d7a4410149fddc4e86986daeb_LowRes.png)
To do that, do the following in the Matrix Report:
  1. Set the X and Y axis to TIME Classification and Business Capability
  2. Apply the 6R Strategy view from the View drop-down menu, as shown in the following:![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744f5367a441014b648c624d3d3b79a_LowRes.gif)


Another approach would be to focus on applications that take less effort but deliver high business impact to show quick wins. You can just narrow down these applications as described above, but this time focus on those applications that are classified as Rehost or even Replace under the 6R strategy and Invest under TIME.
Perhaps your priority is rationalization and cost optimization. You can easily identify which applications to act on for a quick win by focusing on applications classified as Retire and with the least business impact. You can quickly narrow it down by using the Portfolio Report. In the Application Portfolio Report, set the X and Y axis to 6R Strategy and Business Criticality to identify applications classified both as Retire and as Administrative service.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275108b27a4410148e47d6b2d9bf4f4e_LowRes.gif)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
